# TODO: 封装类似于宏的发送结构, 用于处理prompt参数
from .globals import ctx, session
from .handler import FILTER_SUCCESS, Session, SessionHandler
from .prompt import Prompt

#     💩
#    💩💩
#   💩💩💩
#  💩💩💩💩

__all__ = [
    "ctx",
    "session",
    "FILTER_SUCCESS",
    "Session",
    "SessionHandler",
    "Prompt",
]
